@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::Static::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::Cmd::Static::VERSION = '0.071';
+  $App::DuckPAN::Cmd::Static::VERSION = '0.072';
 }
 # ABSTRACT: Starting up the static webserver
 
@@ -66,11 +66,11 @@ App::DuckPAN::Cmd::Static - Starting up the static webserver
 
 =head1 VERSION
 
-version 0.071
+version 0.072
 
 =head1 AUTHOR
 
-Torsten Raudssus <torsten@raudss.us>
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
 =head1 COPYRIGHT AND LICENSE
 
